@@ -55,13 +55,17 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
         from the server.
 
         """
-        vortexUuids = set(VortexFactory.getRemoteVortexUuids()) & self._uuidsObserving
+        vortexUuids = (
+            set(VortexFactory.getRemoteVortexUuids()) & self._uuidsObserving
+        )
         self._uuidsObserving = vortexUuids
 
         payloadsByVortexUuid = defaultdict(Payload)
 
         for chunkKey in chunkKeys:
-            encodedChunkedIndexChunk = self._cacheController.encodedChunk(chunkKey)
+            encodedChunkedIndexChunk = self._cacheController.encodedChunk(
+                chunkKey
+            )
 
             # Queue up the required client notifications
             for vortexUuid in vortexUuids:
@@ -70,7 +74,9 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
                     chunkKey,
                     vortexUuid,
                 )
-                payloadsByVortexUuid[vortexUuid].tuples.append(encodedChunkedIndexChunk)
+                payloadsByVortexUuid[vortexUuid].tuples.append(
+                    encodedChunkedIndexChunk
+                )
 
         # Send the updates to the clients
         dl = []
@@ -79,8 +85,12 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
 
             # Serialise in thread, and then send.
             d = payload.makePayloadEnvelopeDefer()
-            d.addCallback(lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer())
-            d.addCallback(VortexFactory.sendVortexMsg, destVortexUuid=vortexUuid)
+            d.addCallback(
+                lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer()
+            )
+            d.addCallback(
+                VortexFactory.sendVortexMsg, destVortexUuid=vortexUuid
+            )
             dl.append(d)
 
         # Log the errors, otherwise we don't care about them
@@ -174,8 +184,9 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
             )
 
         # Send the payload to the frontend
-        payload = Payload(filt=filt, tuples=chunkedIndexTuplesToSend)
-        d: Deferred = payload.makePayloadEnvelopeDefer()
-        d.addCallback(lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer())
+        payloadEnvelope = PayloadEnvelope(
+            filt=filt, data=chunkedIndexTuplesToSend
+        )
+        d: Deferred = payloadEnvelope.toVortexMsgDefer(base64Encode=False)
         d.addCallback(sendResponse)
         d.addErrback(vortexLogFailure, self._logger, consumeError=True)
